Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(428)

Unified Diff: chrome/browser/ui/bookmarks/bookmark_tab_helper_delegate.h

Issue 7013001: Rename BookmarksTabHelper to BookmarkTabHelper. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 9 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/bookmarks/bookmark_tab_helper_delegate.h
diff --git a/chrome/browser/ui/bookmarks/bookmarks_tab_helper_delegate.h b/chrome/browser/ui/bookmarks/bookmark_tab_helper_delegate.h
similarity index 58%
rename from chrome/browser/ui/bookmarks/bookmarks_tab_helper_delegate.h
rename to chrome/browser/ui/bookmarks/bookmark_tab_helper_delegate.h
index d79e028f57f37e9ffdb3f60d9b51e229e5ca04a0..4f1942ca9d9762d9c7b6f96082d80f536e94d75b 100644
--- a/chrome/browser/ui/bookmarks/bookmarks_tab_helper_delegate.h
+++ b/chrome/browser/ui/bookmarks/bookmark_tab_helper_delegate.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_BROWSER_UI_BOOKMARKS_BOOKMARKS_TAB_HELPER_DELEGATE_H_
-#define CHROME_BROWSER_UI_BOOKMARKS_BOOKMARKS_TAB_HELPER_DELEGATE_H_
+#ifndef CHROME_BROWSER_UI_BOOKMARKS_BOOKMARK_TAB_HELPER_DELEGATE_H_
+#define CHROME_BROWSER_UI_BOOKMARKS_BOOKMARK_TAB_HELPER_DELEGATE_H_
#pragma once
#include "base/basictypes.h"
@@ -11,14 +11,14 @@
class TabContentsWrapper;
// Objects implement this interface to get notified about changes in the
-// BookmarksTabHelper and to provide necessary functionality.
-class BookmarksTabHelperDelegate {
+// BookmarkTabHelper and to provide necessary functionality.
+class BookmarkTabHelperDelegate {
public:
// Notification that the starredness of the current URL changed.
virtual void URLStarredChanged(TabContentsWrapper* source, bool starred) = 0;
protected:
- virtual ~BookmarksTabHelperDelegate();
+ virtual ~BookmarkTabHelperDelegate();
};
-#endif // CHROME_BROWSER_UI_BOOKMARKS_BOOKMARKS_TAB_HELPER_DELEGATE_H_
+#endif // CHROME_BROWSER_UI_BOOKMARKS_BOOKMARK_TAB_HELPER_DELEGATE_H_
« no previous file with comments | « chrome/browser/ui/bookmarks/bookmark_tab_helper.cc ('k') | chrome/browser/ui/bookmarks/bookmark_tab_helper_delegate.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698